.. Tendril documentation master file, created by
   sphinx-quickstart on Sun Dec 28 19:09:19 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

=====================
Tendril documentation
=====================

.. include:: ../README.rst

.. toctree::
   :maxdepth: 4

   userdoc/userdoc
   devdoc/devdoc
   apidoc/tendril
   other

*  :ref:`genindex`
*  :ref:`modindex`
*  :ref:`search`

